@@ -117,13 +117,11 @@ g_data_input_stream_set_property (GObject      *object,
 				  const GValue *value,
 				  GParamSpec   *pspec)
 {
-  GDataInputStreamPrivate *priv;
   GDataInputStream        *dstream;
 
   dstream = G_DATA_INPUT_STREAM (object);
-  priv = dstream->priv;
 
-   switch (prop_id) 
+   switch (prop_id)
     {
     case PROP_BYTE_ORDER:
       g_data_input_stream_set_byte_order (dstream, g_value_get_enum (value));
@@ -360,7 +358,7 @@ g_data_input_stream_read_byte (GDataInputStream  *stream,
  * Reads a 16-bit/2-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order().
+ * see g_data_input_stream_get_byte_order() and g_data_input_stream_set_byte_order().
  * 
  * Returns: a signed 16-bit/2-byte value read from @stream or %0 if 
  * an error occurred.
@@ -404,7 +402,7 @@ g_data_input_stream_read_int16 (GDataInputStream  *stream,
  * Reads an unsigned 16-bit/2-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order(). 
+ * see g_data_input_stream_get_byte_order() and g_data_input_stream_set_byte_order(). 
  * 
  * Returns: an unsigned 16-bit/2-byte value read from the @stream or %0 if 
  * an error occurred. 
@@ -448,7 +446,7 @@ g_data_input_stream_read_uint16 (GDataInputStream  *stream,
  * Reads a signed 32-bit/4-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order().
+ * see g_data_input_stream_get_byte_order() and g_data_input_stream_set_byte_order().
  *
  * If @cancellable is not %NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
@@ -496,7 +494,7 @@ g_data_input_stream_read_int32 (GDataInputStream  *stream,
  * Reads an unsigned 32-bit/4-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order().
+ * see g_data_input_stream_get_byte_order() and g_data_input_stream_set_byte_order().
  *
  * If @cancellable is not %NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
@@ -544,7 +542,7 @@ g_data_input_stream_read_uint32 (GDataInputStream  *stream,
  * Reads a 64-bit/8-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order() and g_data_stream_set_byte_order().
+ * see g_data_input_stream_get_byte_order() and g_data_input_stream_set_byte_order().
  *
  * If @cancellable is not %NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
@@ -592,7 +590,7 @@ g_data_input_stream_read_int64 (GDataInputStream  *stream,
  * Reads an unsigned 64-bit/8-byte value from @stream.
  *
  * In order to get the correct byte order for this read operation, 
- * see g_data_stream_get_byte_order().
+ * see g_data_input_stream_get_byte_order().
  *
  * If @cancellable is not %NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
@@ -817,21 +815,16 @@ scan_for_chars (GDataInputStream *stream,
 		const char       *stop_chars)
 {
   GBufferedInputStream *bstream;
-  GDataInputStreamPrivate *priv;
   const char *buffer;
   gsize start, end, peeked;
   int i;
-  gssize found_pos;
   gsize available, checked;
   const char *stop_char;
 
-  priv = stream->priv;
-  
   bstream = G_BUFFERED_INPUT_STREAM (stream);
 
   checked = *checked_out;
-  found_pos = -1;
-  
+
   start = checked;
   buffer = (const char *)g_buffered_input_stream_peek_buffer (bstream, &available) + start;
   end = available;
@@ -863,6 +856,9 @@ scan_for_chars (GDataInputStream *stream,
  * Reads a string from the data input stream, up to the first
  * occurrence of any of the stop characters.
  *
+ * Note that, in contrast to g_data_input_stream_read_until_async(),
+ * this function consumes the stop character that it finds.
+ *
  * Returns: a string with the data that was read before encountering
  *     any of the stop characters. Set @length to a #gsize to get the length
  *     of the string. This function will return %NULL on an error.
@@ -1165,6 +1161,10 @@ g_data_input_stream_read_line_async (GDataInputStream    *stream,
  * The asynchronous version of g_data_input_stream_read_until().
  * It is an error to have two outstanding calls to this function.
  *
+ * Note that, in contrast to g_data_input_stream_read_until(),
+ * this function does not consume the stop character that it finds.  You
+ * must read it for yourself.
+ *
  * When the operation is finished, @callback will be called. You
  * can then call g_data_input_stream_read_until_finish() to get
  * the result of the operation.
@@ -1203,7 +1203,7 @@ g_data_input_stream_read_until_async (GDataInputStream    *stream,
  *     On an error, it will return %NULL and @error will be set. If there's no
  *     content to read, it will still return %NULL, but @error won't be set.
  *
- * Since: 2,20
+ * Since: 2.20
  */
 gchar *
 g_data_input_stream_read_line_finish (GDataInputStream  *stream,
