@@ -77,14 +77,7 @@ struct _GDBusConnectionClass
 
   /*< private >*/
   /* Padding for future expansion */
-  void (*_g_reserved1) (void);
-  void (*_g_reserved2) (void);
-  void (*_g_reserved3) (void);
-  void (*_g_reserved4) (void);
-  void (*_g_reserved5) (void);
-  void (*_g_reserved6) (void);
-  void (*_g_reserved7) (void);
-  void (*_g_reserved8) (void);
+  gpointer padding[64];
 };
 
 GType            g_dbus_connection_get_type                   (void) G_GNUC_CONST;
@@ -304,14 +297,7 @@ struct _GDBusInterfaceVTable
 
   /*< private >*/
   /* Padding for future expansion */
-  void (*_g_reserved1) (void);
-  void (*_g_reserved2) (void);
-  void (*_g_reserved3) (void);
-  void (*_g_reserved4) (void);
-  void (*_g_reserved5) (void);
-  void (*_g_reserved6) (void);
-  void (*_g_reserved7) (void);
-  void (*_g_reserved8) (void);
+  gpointer padding[8];
 };
 
 guint            g_dbus_connection_register_object            (GDBusConnection            *connection,
@@ -469,6 +455,8 @@ void             g_dbus_connection_signal_unsubscribe         (GDBusConnection
  * GDBusMessageFilterFunction:
  * @connection: A #GDBusConnection.
  * @message: A #GDBusMessage.
+ * @incoming: %TRUE if it is a message received from the other peer, %FALSE if it is
+ * a message to be sent to the other peer.
  * @user_data: User data passed when adding the filter.
  *
  * Signature for function used in g_dbus_connection_add_filter().
@@ -480,6 +468,7 @@ void             g_dbus_connection_signal_unsubscribe         (GDBusConnection
  */
 typedef gboolean (*GDBusMessageFilterFunction) (GDBusConnection *connection,
                                                 GDBusMessage    *message,
+                                                gboolean         incoming,
                                                 gpointer         user_data);
 
 guint g_dbus_connection_add_filter (GDBusConnection            *connection,
