@@ -20,6 +20,10 @@
  * Author: David Zeuthen <davidz@redhat.com>
  */
 
+#if !defined (__GIO_GIO_H_INSIDE__) && !defined (GIO_COMPILATION)
+#error "Only <gio/gio.h> can be included directly."
+#endif
+
 #ifndef __G_DBUS_MESSAGE_H__
 #define __G_DBUS_MESSAGE_H__
 
@@ -48,6 +52,10 @@ struct _GDBusMessageClass
 {
   /*< private >*/
   GObjectClass parent_class;
+
+  /*< private >*/
+  /* Padding for future expansion */
+  gpointer padding[32];
 };
 
 /**
