@@ -22,6 +22,7 @@
 #define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
 #define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
@@ -45,6 +46,7 @@
 #define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
 
@@ -126,7 +128,44 @@ _gio_marshal_VOID__STRING_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOOLEAN,POINTER (./gio-marshal.list:3) */
+/* VOID:STRING,VARIANT (./gio-marshal.list:3) */
+void
+_gio_marshal_VOID__STRING_VARIANT (GClosure     *closure,
+                                   GValue       *return_value G_GNUC_UNUSED,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
+                                   gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_VARIANT) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     arg_2,
+                                                     gpointer     data2);
+  register GMarshalFunc_VOID__STRING_VARIANT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_VARIANT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_variant (param_values + 2),
+            data2);
+}
+
+/* VOID:BOOLEAN,POINTER (./gio-marshal.list:4) */
 void
 _gio_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -163,7 +202,7 @@ _gio_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,ENUM (./gio-marshal.list:4) */
+/* VOID:OBJECT,OBJECT,ENUM (./gio-marshal.list:5) */
 void
 _gio_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -202,7 +241,7 @@ _gio_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (./gio-marshal.list:5) */
+/* BOOLEAN:OBJECT,OBJECT (./gio-marshal.list:6) */
 void
 _gio_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -243,7 +282,7 @@ _gio_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:STRING,BOXED,BOXED (./gio-marshal.list:6) */
+/* VOID:STRING,BOXED,BOXED (./gio-marshal.list:7) */
 void
 _gio_marshal_VOID__STRING_BOXED_BOXED (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -282,7 +321,7 @@ _gio_marshal_VOID__STRING_BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* BOOL:POINTER,INT (./gio-marshal.list:7) */
+/* BOOL:POINTER,INT (./gio-marshal.list:8) */
 void
 _gio_marshal_BOOLEAN__POINTER_INT (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -323,7 +362,7 @@ _gio_marshal_BOOLEAN__POINTER_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:UINT (./gio-marshal.list:8) */
+/* BOOL:UINT (./gio-marshal.list:9) */
 void
 _gio_marshal_BOOLEAN__UINT (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -362,7 +401,83 @@ _gio_marshal_BOOLEAN__UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:STRING,STRING,BOXED (./gio-marshal.list:9) */
+/* BOOL:VARIANT (./gio-marshal.list:10) */
+void
+_gio_marshal_BOOLEAN__VARIANT (GClosure     *closure,
+                               GValue       *return_value G_GNUC_UNUSED,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VARIANT) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     data2);
+  register GMarshalFunc_BOOLEAN__VARIANT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__VARIANT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_variant (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOL:VOID (./gio-marshal.list:11) */
+void
+_gio_marshal_BOOLEAN__VOID (GClosure     *closure,
+                            GValue       *return_value G_GNUC_UNUSED,
+                            guint         n_param_values,
+                            const GValue *param_values,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
+                            gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
+                                                  gpointer     data2);
+  register GMarshalFunc_BOOLEAN__VOID callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 1);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__VOID) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* VOID:STRING,STRING,BOXED (./gio-marshal.list:12) */
 void
 _gio_marshal_VOID__STRING_STRING_BOXED (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -401,7 +516,7 @@ _gio_marshal_VOID__STRING_STRING_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOOL,BOXED (./gio-marshal.list:10) */
+/* VOID:BOOL,BOXED (./gio-marshal.list:13) */
 void
 _gio_marshal_VOID__BOOLEAN_BOXED (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -438,20 +553,20 @@ _gio_marshal_VOID__BOOLEAN_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED (./gio-marshal.list:11) */
+/* VOID:VARIANT,VARIANT (./gio-marshal.list:14) */
 void
-_gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
-                                GValue       *return_value G_GNUC_UNUSED,
-                                guint         n_param_values,
-                                const GValue *param_values,
-                                gpointer      invocation_hint G_GNUC_UNUSED,
-                                gpointer      marshal_data)
+_gio_marshal_VOID__VARIANT_VARIANT (GClosure     *closure,
+                                    GValue       *return_value G_GNUC_UNUSED,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                    gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__BOXED_BOXED) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gpointer     arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__BOXED_BOXED callback;
+  typedef void (*GMarshalFunc_VOID__VARIANT_VARIANT) (gpointer     data1,
+                                                      gpointer     arg_1,
+                                                      gpointer     arg_2,
+                                                      gpointer     data2);
+  register GMarshalFunc_VOID__VARIANT_VARIANT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -467,17 +582,17 @@ _gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__BOXED_BOXED) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__VARIANT_VARIANT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_marshal_value_peek_boxed (param_values + 1),
-            g_marshal_value_peek_boxed (param_values + 2),
+            g_marshal_value_peek_variant (param_values + 1),
+            g_marshal_value_peek_variant (param_values + 2),
             data2);
 }
 
-/* VOID:INT (./gio-marshal.list:12) */
+/* VOID:INT (./gio-marshal.list:15) */
 
-/* VOID:STRING,INT (./gio-marshal.list:13) */
+/* VOID:STRING,INT (./gio-marshal.list:16) */
 void
 _gio_marshal_VOID__STRING_INT (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -514,7 +629,7 @@ _gio_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,UINT (./gio-marshal.list:14) */
+/* VOID:STRING,UINT (./gio-marshal.list:17) */
 void
 _gio_marshal_VOID__STRING_UINT (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -551,5 +666,116 @@ _gio_marshal_VOID__STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED (./gio-marshal.list:15) */
+/* VOID:BOXED,BOXED (./gio-marshal.list:18) */
+void
+_gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
+                                GValue       *return_value G_GNUC_UNUSED,
+                                guint         n_param_values,
+                                const GValue *param_values,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
+                                gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__BOXED_BOXED) (gpointer     data1,
+                                                  gpointer     arg_1,
+                                                  gpointer     arg_2,
+                                                  gpointer     data2);
+  register GMarshalFunc_VOID__BOXED_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__BOXED_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_boxed (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
+}
+
+/* VOID:VARIANT,BOXED (./gio-marshal.list:19) */
+void
+_gio_marshal_VOID__VARIANT_BOXED (GClosure     *closure,
+                                  GValue       *return_value G_GNUC_UNUSED,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__VARIANT_BOXED) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     arg_2,
+                                                    gpointer     data2);
+  register GMarshalFunc_VOID__VARIANT_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__VARIANT_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_variant (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
+}
+
+/* VOID:STRING,STRING,VARIANT (./gio-marshal.list:20) */
+void
+_gio_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
+                                          GValue       *return_value G_GNUC_UNUSED,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
+                                          gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_VARIANT) (gpointer     data1,
+                                                            gpointer     arg_1,
+                                                            gpointer     arg_2,
+                                                            gpointer     arg_3,
+                                                            gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_VARIANT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING_VARIANT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_variant (param_values + 3),
+            data2);
+}
 
