@@ -22,7 +22,15 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:BOOLEAN,POINTER (./gio-marshal.list:3) */
+/* VOID:STRING,VARIANT (./gio-marshal.list:3) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_VARIANT (GClosure     *closure,
+                                                        GValue       *return_value,
+                                                        guint         n_param_values,
+                                                        const GValue *param_values,
+                                                        gpointer      invocation_hint,
+                                                        gpointer      marshal_data);
+
+/* VOID:BOOLEAN,POINTER (./gio-marshal.list:4) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -30,7 +38,7 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,ENUM (./gio-marshal.list:4) */
+/* VOID:OBJECT,OBJECT,ENUM (./gio-marshal.list:5) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -38,7 +46,7 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__OBJECT_OBJECT_ENUM (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* BOOLEAN:OBJECT,OBJECT (./gio-marshal.list:5) */
+/* BOOLEAN:OBJECT,OBJECT (./gio-marshal.list:6) */
 G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -46,7 +54,7 @@ G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* VOID:STRING,BOXED,BOXED (./gio-marshal.list:6) */
+/* VOID:STRING,BOXED,BOXED (./gio-marshal.list:7) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_BOXED_BOXED (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -54,7 +62,7 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_BOXED_BOXED (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* BOOL:POINTER,INT (./gio-marshal.list:7) */
+/* BOOL:POINTER,INT (./gio-marshal.list:8) */
 G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__POINTER_INT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -63,7 +71,7 @@ G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__POINTER_INT (GClosure     *closure,
                                                         gpointer      marshal_data);
 #define _gio_marshal_BOOL__POINTER_INT	_gio_marshal_BOOLEAN__POINTER_INT
 
-/* BOOL:UINT (./gio-marshal.list:8) */
+/* BOOL:UINT (./gio-marshal.list:9) */
 G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__UINT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -72,7 +80,25 @@ G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__UINT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define _gio_marshal_BOOL__UINT	_gio_marshal_BOOLEAN__UINT
 
-/* VOID:STRING,STRING,BOXED (./gio-marshal.list:9) */
+/* BOOL:VARIANT (./gio-marshal.list:10) */
+G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__VARIANT (GClosure     *closure,
+                                                    GValue       *return_value,
+                                                    guint         n_param_values,
+                                                    const GValue *param_values,
+                                                    gpointer      invocation_hint,
+                                                    gpointer      marshal_data);
+#define _gio_marshal_BOOL__VARIANT	_gio_marshal_BOOLEAN__VARIANT
+
+/* BOOL:VOID (./gio-marshal.list:11) */
+G_GNUC_INTERNAL void _gio_marshal_BOOLEAN__VOID (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+#define _gio_marshal_BOOL__VOID	_gio_marshal_BOOLEAN__VOID
+
+/* VOID:STRING,STRING,BOXED (./gio-marshal.list:12) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_STRING_BOXED (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -80,7 +106,7 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_STRING_BOXED (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:BOOL,BOXED (./gio-marshal.list:10) */
+/* VOID:BOOL,BOXED (./gio-marshal.list:13) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_BOXED (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -89,18 +115,18 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__BOOLEAN_BOXED (GClosure     *closure,
                                                        gpointer      marshal_data);
 #define _gio_marshal_VOID__BOOL_BOXED	_gio_marshal_VOID__BOOLEAN_BOXED
 
-/* VOID:BOXED,BOXED (./gio-marshal.list:11) */
-G_GNUC_INTERNAL void _gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
-                                                     GValue       *return_value,
-                                                     guint         n_param_values,
-                                                     const GValue *param_values,
-                                                     gpointer      invocation_hint,
-                                                     gpointer      marshal_data);
+/* VOID:VARIANT,VARIANT (./gio-marshal.list:14) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__VARIANT_VARIANT (GClosure     *closure,
+                                                         GValue       *return_value,
+                                                         guint         n_param_values,
+                                                         const GValue *param_values,
+                                                         gpointer      invocation_hint,
+                                                         gpointer      marshal_data);
 
-/* VOID:INT (./gio-marshal.list:12) */
+/* VOID:INT (./gio-marshal.list:15) */
 #define _gio_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 
-/* VOID:STRING,INT (./gio-marshal.list:13) */
+/* VOID:STRING,INT (./gio-marshal.list:16) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_INT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -108,7 +134,7 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_INT (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* VOID:STRING,UINT (./gio-marshal.list:14) */
+/* VOID:STRING,UINT (./gio-marshal.list:17) */
 G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -116,7 +142,29 @@ G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED (./gio-marshal.list:15) */
+/* VOID:BOXED,BOXED (./gio-marshal.list:18) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__BOXED_BOXED (GClosure     *closure,
+                                                     GValue       *return_value,
+                                                     guint         n_param_values,
+                                                     const GValue *param_values,
+                                                     gpointer      invocation_hint,
+                                                     gpointer      marshal_data);
+
+/* VOID:VARIANT,BOXED (./gio-marshal.list:19) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__VARIANT_BOXED (GClosure     *closure,
+                                                       GValue       *return_value,
+                                                       guint         n_param_values,
+                                                       const GValue *param_values,
+                                                       gpointer      invocation_hint,
+                                                       gpointer      marshal_data);
+
+/* VOID:STRING,STRING,VARIANT (./gio-marshal.list:20) */
+G_GNUC_INTERNAL void _gio_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
+                                                               GValue       *return_value,
+                                                               guint         n_param_values,
+                                                               const GValue *param_values,
+                                                               gpointer      invocation_hint,
+                                                               gpointer      marshal_data);
 
 G_END_DECLS
 
