@@ -26,7 +26,7 @@
 #ifndef __G_SETTINGS_H__
 #define __G_SETTINGS_H__
 
-#include <glib-object.h>
+#include <gio/giotypes.h>
 
 G_BEGIN_DECLS
 
@@ -42,7 +42,6 @@ G_BEGIN_DECLS
 
 typedef struct _GSettingsPrivate                            GSettingsPrivate;
 typedef struct _GSettingsClass                              GSettingsClass;
-typedef struct _GSettings                                   GSettings;
 
 struct _GSettingsClass
 {
@@ -71,15 +70,16 @@ struct _GSettings
 
 GType                   g_settings_get_type                             (void);
 
+const gchar * const *   g_settings_list_schemas                         (void);
 GSettings *             g_settings_new                                  (const gchar        *schema);
 GSettings *             g_settings_new_with_path                        (const gchar        *schema,
                                                                          const gchar        *path);
-gboolean                g_settings_supports_context                     (const gchar        *context);
-GSettings *             g_settings_new_with_context                     (const gchar        *schema,
-                                                                         const gchar        *context);
-GSettings *             g_settings_new_with_context_and_path            (const gchar        *schema,
-                                                                         const gchar        *context,
+GSettings *             g_settings_new_with_backend                     (const gchar        *schema,
+                                                                         GSettingsBackend   *backend);
+GSettings *             g_settings_new_with_backend_and_path            (const gchar        *schema,
+                                                                         GSettingsBackend   *backend,
                                                                          const gchar        *path);
+const gchar **          g_settings_list_keys                            (GSettings          *settings);
 
 gboolean                g_settings_set_value                            (GSettings          *settings,
                                                                          const gchar        *key,
@@ -121,7 +121,11 @@ gchar **                g_settings_get_strv                             (GSettin
 gboolean                g_settings_set_strv                             (GSettings          *settings,
                                                                          const gchar        *key,
                                                                          const gchar *const *value);
-
+gint                    g_settings_get_enum                             (GSettings          *settings,
+                                                                         const gchar        *key);
+gboolean                g_settings_set_enum                             (GSettings          *settings,
+                                                                         const gchar        *key,
+                                                                         gint                value);
 GSettings *             g_settings_get_child                            (GSettings          *settings,
                                                                          const gchar        *name);
 
@@ -132,6 +136,7 @@ void                    g_settings_delay                                (GSettin
 void                    g_settings_apply                                (GSettings          *settings);
 void                    g_settings_revert                               (GSettings          *settings);
 gboolean                g_settings_get_has_unapplied                    (GSettings          *settings);
+void                    g_settings_sync                                 (void);
 
 /**
  * GSettingsBindSetMapping:
