@@ -20,6 +20,10 @@
  * Author: Ryan Lortie <desrt@desrt.ca>
  */
 
+#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
+#error "Only <glib.h> can be included directly."
+#endif
+
 #ifndef __G_VARIANT_H__
 #define __G_VARIANT_H__
 
@@ -55,6 +59,7 @@ typedef enum
 void                            g_variant_unref                         (GVariant             *value);
 GVariant *                      g_variant_ref                           (GVariant             *value);
 GVariant *                      g_variant_ref_sink                      (GVariant             *value);
+gboolean                        g_variant_is_floating                   (GVariant             *value);
 
 const GVariantType *            g_variant_get_type                      (GVariant             *value);
 const gchar *                   g_variant_get_type_string               (GVariant             *value);
@@ -179,7 +184,12 @@ struct _GVariantBuilder {
   gsize x[16];
 };
 
+typedef enum
+{
+  G_VARIANT_PARSE_ERROR_FAILED
+} GVariantParseError;
 #define G_VARIANT_PARSE_ERROR (g_variant_parser_get_error_quark ())
+
 GQuark                          g_variant_parser_get_error_quark        (void);
 
 GVariantBuilder *               g_variant_builder_new                   (const GVariantType   *type);
